@@ -243,6 +243,15 @@ class RoborockFanSpeedQ7Max(RoborockFanPowerCode):
     max = 104
 
 
+class RoborockFanSpeedQRevoMaster(RoborockFanPowerCode):
+    quiet = 101
+    balanced = 102
+    turbo = 103
+    max = 104
+    max_plus = 105
+    custom = 110  # Smartplan
+
+
 class RoborockFanSpeedP10(RoborockFanPowerCode):
     off = 105
     quiet = 101
@@ -288,6 +297,7 @@ class RoborockMopModeS8ProUltra(RoborockMopModeCode):
 class RoborockMopModeS8MaxVUltra(RoborockMopModeCode):
     standard = 300
     deep = 301
+    custom = 302
     deep_plus = 303
     fast = 304
     deep_plus_pearl = 305
@@ -318,6 +328,17 @@ class RoborockMopIntensityV2(RoborockMopIntensityCode):
     custom = 207
 
 
+class RoborockMopIntensityQRevoMaster(RoborockMopIntensityCode):
+    """Describes the mop intensity of the vacuum cleaner."""
+
+    off = 200
+    low = 201
+    medium = 202
+    high = 203
+    custom_water_flow = 207
+    custom = 209  # SmartPlan
+
+
 class RoborockMopIntensityP10(RoborockMopIntensityCode):
     """Describes the mop intensity of the vacuum cleaner."""
 
@@ -362,6 +383,16 @@ class RoborockMopIntensityS6MaxV(RoborockMopIntensityCode):
     custom_water_flow = 207
 
 
+class RoborockMopIntensityQ7Max(RoborockMopIntensityCode):
+    """Describes the mop intensity of the vacuum cleaner."""
+
+    off = 200
+    low = 201
+    medium = 202
+    high = 203
+    custom_water_flow = 207
+
+
 class RoborockDockErrorCode(RoborockEnum):
     """Describes the error code of the dock."""
 
